@@ -8,7 +8,7 @@ use Symbol ();
 use POSIX ();
 use Config;
 
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 use constant {
     INET_ATON     => 0,
@@ -125,7 +125,7 @@ sub CLOSE {}
 sub DESTROY {
     my $self = shift;
     
-    if ($self->need_result) {
+    if ($self->need_result && $self->{rs}) {
         $self->{rs}->timedout($self->{fd});
     }
 }
